@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -76,12 +76,6 @@
                 refer_to   => '- element',
             },
 
-            [qw/write_config_dir read_config_dir/] => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                status     => 'deprecated',
-            },
-
             generated_by => {
                 type       => 'leaf',
                 value_type => 'uniline',
@@ -129,8 +123,45 @@
         ],
     ],
 
+    [
+        name => 'Itself::ConfigWR::DefaultLayer',
+
+        'element'     => [
+            'config_dir' => {
+                type         => 'leaf',
+                value_type   => 'uniline',
+                level        => 'normal',
+            },
+
+            os_config_dir => {
+                type => 'hash',
+                index_type => 'string',
+                cargo      => {
+                    type       => 'leaf',
+                    value_type => 'uniline',
+                },
+                summary => 'configuration file directory for specific OS',
+                description => 'Specify and alternate location of a configuration directory depending '
+                    .q!on the OS (as returned by C<$^O> or C<$Config{'osname'}>, see L<perlport/PLATFORMS>) !
+                    .q!Common values for C<$^O> are 'linux', 'MSWin32', 'darwin'!
+            },
+            'file' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'normal',
+                summary    => 'target configuration file name',
+                description => 'specify the configuration file name. This parameter may '
+                    .'not be applicable depending on your application. It may also be '
+                    .'hardcoded in a custom backend. If not specified, the instance name '
+                    .'will be used as base name for your configuration file.',
+            },
+        ]
+    ],
+
     [
         name => "Itself::ConfigWR",
+        include => "Itself::ConfigWR::DefaultLayer",
+        include_after => 'backend',
 
         'element' => [
 
@@ -168,17 +199,15 @@
                }
             },
 
-            'file' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                level      => 'normal',
-                summary    => 'target configuration file name',
-                description =>
-'specify the configuration file name. This parameter may not be applicable depending on your application. It may also be hardcoded in a custom backend. If not specified, the instance name will be used as base name for your configuration file.',
-                migrate_from => {
-                    variables => { old => '- config_file' },
-                    formula   => '$old',
-                }
+
+            default_layer => {
+                type => 'node',
+                config_class_name => 'Itself::ConfigWR::DefaultLayer',
+                summary => q!How to find default values in a global config file!,
+                description => q!Specifies where to find a global configuration file that !
+                    .q!specifies default values. For instance, this is used by OpenSSH to !
+                    .q!specify a global configuration file (C</etc/ssh/ssh_config>) that is !
+                    .q!overridden by user's file!,
             },
 
             'class' => {
@@ -291,16 +320,6 @@
                 }
             },
 
-
-            'config_file' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                status     => 'deprecated',
-                level      => 'normal',
-                description =>
-'Specify the configuration file (without path) that will store configuration information',
-            },
-
              'full_dump' => {
                 type             => 'leaf',
                 value_type       => 'boolean',
@@ -348,16 +367,6 @@
                 }
             },
 
-            'config_dir' => {
-                type         => 'leaf',
-                value_type   => 'uniline',
-                level        => 'normal',
-                migrate_from => {
-                    formula   => '$old',
-                    variables => { old => '- - read_config_dir' },
-                }
-            },
-
             'auto_create' => {
                 type             => 'leaf',
                 value_type       => 'boolean',
@@ -401,16 +410,6 @@
                     ],
                 }
             },
-            'config_dir' => {
-                type         => 'leaf',
-                value_type   => 'uniline',
-                level        => 'normal',
-                mandatory    => 1,
-                migrate_from => {
-                    formula   => '$old',
-                    variables => { old => '- - write_config_dir' },
-                }
-            },
 
             # move to ConfigRW when removing legacy allow_empty
             'auto_create' => {
